@@ -12,10 +12,25 @@ def parse_options():
     parser = OptionParser(usage="lurl [options]")
 
     parser.add_option(
-        '-c','--curl',
-        dest='curl',
+        '-p','--prod',
+        dest='curl_prod',
         default=None,
-        help="put your cURL"
+        help="put your cURL for production"
+    )
+
+    parser.add_option(
+       '-s','--stag',
+        dest='curl_stag',
+        default=None,
+        help="put your cURL for staging"
+    )
+
+    parser.add_option(
+       '--skip-response',
+        dest='skip_response',
+        action='store_true',
+        default=False,
+        help="skip set response"
     )
 
     # Finalize
